/****************************************************************************
** Meta object code from reading C++ file 'mainContext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../filelight-26.04.3/src/mainContext.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainContext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Filelight11MainContextE_t {};
} // unnamed namespace

template <> constexpr inline auto Filelight::MainContext::qt_create_metaobjectdata<qt_meta_tag_ZN9Filelight11MainContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Filelight::MainContext",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "canceled",
        "",
        "urlChanged",
        "upEnabledChanged",
        "openUrlFailed",
        "text",
        "explanation",
        "scan",
        "u",
        "slotUp",
        "slotScanFolder",
        "slotScanHomeFolder",
        "slotScanRootFolder",
        "slotScanUrl",
        "QUrl",
        "slotScanPath",
        "openUrl",
        "updateURL",
        "rescanSingleDir",
        "prettyUrl",
        "url",
        "start",
        "upEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canceled'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'upEnabledChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openUrlFailed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'scan'
        QtMocHelpers::SlotData<void(const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'slotUp'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotScanFolder'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotScanHomeFolder'
        QtMocHelpers::SlotData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotScanRootFolder'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotScanUrl'
        QtMocHelpers::SlotData<bool(const QUrl &)>(18, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 19, 6 },
        }}),
        // Slot 'slotScanPath'
        QtMocHelpers::SlotData<bool(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<bool(const QUrl &)>(21, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 19, 6 },
        }}),
        // Slot 'updateURL'
        QtMocHelpers::SlotData<void(const QUrl &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 6 },
        }}),
        // Slot 'rescanSingleDir'
        QtMocHelpers::SlotData<void(const QUrl &) const>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 6 },
        }}),
        // Method 'prettyUrl'
        QtMocHelpers::MethodData<QString(const QUrl &) const>(24, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 19, 25 },
        }}),
        // Method 'start'
        QtMocHelpers::MethodData<bool(const QUrl &) const>(26, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 19, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(25, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'upEnabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MainContext, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Filelight::MainContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Filelight11MainContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Filelight11MainContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Filelight11MainContextE_t>.metaTypes,
    nullptr
} };

void Filelight::MainContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canceled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->urlChanged(); break;
        case 2: _t->upEnabledChanged(); break;
        case 3: _t->openUrlFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->scan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->slotUp(); break;
        case 6: _t->slotScanFolder(); break;
        case 7: _t->slotScanHomeFolder(); break;
        case 8: _t->slotScanRootFolder(); break;
        case 9: { bool _r = _t->slotScanUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->slotScanPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->updateURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->rescanSingleDir((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: { QString _r = _t->prettyUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->start((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainContext::*)(const QString & )>(_a, &MainContext::canceled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainContext::*)()>(_a, &MainContext::urlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainContext::*)()>(_a, &MainContext::upEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainContext::*)(const QString & , const QString & )>(_a, &MainContext::openUrlFailed, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_upEnabled; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_upEnabled, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->upEnabledChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *Filelight::MainContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Filelight::MainContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Filelight11MainContextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Filelight::MainContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Filelight::MainContext::canceled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Filelight::MainContext::urlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Filelight::MainContext::upEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Filelight::MainContext::openUrlFailed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
