// This file is generated by kconfig_compiler_kf6 from filelightsettings.kcfg.
// All changes you do to this file will be lost.

#include "filelightsettings.h"

FilelightSettings::FilelightSettings( )
  : KConfigSkeleton( QStringLiteral( "filelightrc" ) )
{
  setCurrentGroup( QStringLiteral( "filelight_part" ) );

  KConfigSkeleton::ItemBool  *itemScanAcrossMounts;
  itemScanAcrossMounts = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "scanAcrossMounts" ), mScanAcrossMounts, false );
  addItem( itemScanAcrossMounts, QStringLiteral( "scanAcrossMounts" ) );
  KConfigSkeleton::ItemBool  *itemScanRemoteMounts;
  itemScanRemoteMounts = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "scanRemoteMounts" ), mScanRemoteMounts, false );
  addItem( itemScanRemoteMounts, QStringLiteral( "scanRemoteMounts" ) );
  KConfigSkeleton::ItemBool  *itemShowSmallFiles;
  itemShowSmallFiles = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showSmallFiles" ), mShowSmallFiles, false );
  addItem( itemShowSmallFiles, QStringLiteral( "showSmallFiles" ) );
  KConfigSkeleton::ItemBool  *itemShowFoldersSidebar;
  itemShowFoldersSidebar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showFoldersSidebar" ), mShowFoldersSidebar, true );
  addItem( itemShowFoldersSidebar, QStringLiteral( "showFoldersSidebar" ) );
  KConfigSkeleton::ItemInt  *itemContrast;
  itemContrast = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "contrast" ), mContrast, 75 );
  addItem( itemContrast, QStringLiteral( "contrast" ) );
  KConfigSkeleton::ItemInt  *itemScheme;
  itemScheme = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "scheme" ), mScheme, 0 );
  addItem( itemScheme, QStringLiteral( "scheme" ) );
  QStringList defaultskipList;
  defaultskipList.append( QString::fromUtf8( "/dev" ) );
  defaultskipList.append( QString::fromUtf8( "/proc" ) );
  defaultskipList.append( QString::fromUtf8( "/sys" ) );
  defaultskipList.append( QString::fromUtf8( "/root" ) );

  KConfigSkeleton::ItemPathList  *itemSkipList;
  itemSkipList = new KConfigSkeleton::ItemPathList( currentGroup(), QStringLiteral( "skipList" ), mSkipList, defaultskipList );
  addItem( itemSkipList, QStringLiteral( "skipList" ) );
}

FilelightSettings::~FilelightSettings()
{
}

