/****************************************************************************
** Meta object code from reading C++ file 'Config.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../filelight-26.04.3/src/Config.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Config::qt_create_metaobjectdata<qt_meta_tag_ZN6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Config",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "changed",
        "",
        "addFolderFailed",
        "reason",
        "write",
        "addFolder",
        "removeFolder",
        "url",
        "scanAcrossMounts",
        "scanRemoteMounts",
        "showSmallFiles",
        "showFoldersSidebar",
        "contrast",
        "defaultRingDepth",
        "scheme",
        "Filelight::MapScheme",
        "skipList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addFolderFailed'
        QtMocHelpers::SignalData<void(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'write'
        QtMocHelpers::MethodData<void() const>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'addFolder'
        QtMocHelpers::MethodData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'removeFolder'
        QtMocHelpers::MethodData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scanAcrossMounts'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'scanRemoteMounts'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'showSmallFiles'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'showFoldersSidebar'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'contrast'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'defaultRingDepth'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'scheme'
        QtMocHelpers::PropertyData<Filelight::MapScheme>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'skipList'
        QtMocHelpers::PropertyData<QStringList>(21, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Config, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6ConfigE[] = {
    QMetaObject::SuperData::link<Filelight::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Config::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6ConfigE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ConfigE_t>.metaTypes,
    nullptr
} };

void Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->addFolderFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->write(); break;
        case 3: _t->addFolder(); break;
        case 4: _t->removeFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)(const QString & )>(_a, &Config::addFolderFailed, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->scanAcrossMounts; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->scanRemoteMounts; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showSmallFiles; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showFoldersSidebar; break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->contrast; break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->defaultRingDepth; break;
        case 6: *reinterpret_cast<Filelight::MapScheme*>(_v) = _t->scheme; break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->skipList; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->scanAcrossMounts, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->scanRemoteMounts, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->showSmallFiles, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->showFoldersSidebar, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->contrast, *reinterpret_cast<uint*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->defaultRingDepth, *reinterpret_cast<uint*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->scheme, *reinterpret_cast<Filelight::MapScheme*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->skipList, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Config::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Config::addFolderFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN9FilelightE_t {};
} // unnamed namespace

template <> constexpr inline auto Filelight::qt_create_metaobjectdata<qt_meta_tag_ZN9FilelightE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Filelight",
        "QML.Element",
        "auto",
        "Dirty",
        "Layout",
        "Colors",
        "MapScheme",
        "Rainbow",
        "KDE",
        "HighContrast"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Dirty'
        QtMocHelpers::EnumData<Dirty>(3, 3, QMC::EnumIsScoped).add({
            {    4, Dirty::Layout },
            {    5, Dirty::Colors },
        }),
        // enum 'MapScheme'
        QtMocHelpers::EnumData<MapScheme>(6, 6, QMC::EnumFlags{}).add({
            {    7, MapScheme::Rainbow },
            {    8, MapScheme::KDE },
            {    9, MapScheme::HighContrast },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9FilelightE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9FilelightE =
    Filelight::qt_create_metaobjectdata<qt_meta_tag_ZN9FilelightE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9FilelightE =
    qt_staticMetaObjectContent_ZN9FilelightE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9FilelightE =
    qt_staticMetaObjectContent_ZN9FilelightE.relocatingData;

Q_CONSTINIT const QMetaObject Filelight::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9FilelightE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9FilelightE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9FilelightE.metaTypes,
    nullptr
} };

QT_WARNING_POP
